set val(chan)           Channel/WirelessChannel    ;#Channel Type
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail		   ;# interface queue type
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(ifqlen)         50                         ;# max packet in ifq
set val(nn)             10                       ;# number of mobilenodes
set val(rp)             DumbAgent                  ;# routing protocol
set val(x)		50
set val(y)		50

Mac/802_11 set dataRate_ 2Mb
 
# Initialize Global Variables
set ns_		[new Simulator]
set tracefd     [open 802_beacon.tr w]
$ns_ trace-all $tracefd

#set namtrace [open 802.nam w]
#$ns_ namtrace-all-wireless $namtrace  #$val(x) $val(y)

# set up topography object
set topo       [new Topography]

$topo load_flatgrid $val(x) $val(y)

# Create God
create-god $val(nn)

# Create channel
set chan_ [new $val(chan)]


$ns_ node-config -adhocRouting $val(rp) \
		-llType $val(ll) \
		-macType $val(mac) \
		-ifqType $val(ifq) \
		-ifqLen $val(ifqlen) \
		-antType $val(ant) \
		-propType $val(prop) \
		-phyType $val(netif) \
		-topoInstance $topo \
		-agentTrace OFF \
		-routerTrace OFF \
		-macTrace ON \
		-movementTrace OFF \
		-channel $chan_


      for {set i 0} {$i < [expr $val(nn)]} {incr i} {
                  set node_($i) [$ns_ node]
		 
                  $node_($i) random-motion 0              ;# disable random motion
  		set mac_($i) [$node_($i) getMac 0]
 
      		
      		$mac_($i) set RTSThreshold_ 3000
 
  		$node_($i) set X_ 0.0
  		$node_($i) set Y_ 0.0
  		$node_($i) set Z_ 0.0
      }

#Associating nodes only 2 to (val(nn) - 1). Nodes 1 and 0 form a seperate link

set AP_ADDR [$mac_([expr $val(nn) - 1]) id]
for {set i 2} {$i < $val(nn)} {incr i} {
   $mac_($i) bss_id $AP_ADDR
}



puts "Associating ..." 
for {set i 2} {$i < [expr $val(nn) - 1] } {incr i} {
    $mac_([expr $val(nn) - 1]) associate [$mac_($i) id]
}
puts "Associated" 


Application/Traffic/CBR set packetSize_ 1023
Application/Traffic/CBR set rate_ 64Kb


# Setup traffic flow between nodes
for {set i 1} {$i < [expr $val(nn) - 1]} {incr i} {
	set udp($i) [new Agent/UDP]
	$ns_ attach-agent $node_($i) $udp($i)
	set cbr($i) [new Application/Traffic/CBR]
	$cbr($i) attach-agent $udp($i)
}


# Base0 is attached to AP
set base0 [new Agent/Null]
$ns_ attach-agent $node_([expr $val(nn) - 1]) $base0

set base1 [new Agent/Null]
$ns_ attach-agent $node_(0) $base1

for {set i 2} {$i < [expr $val(nn) - 1]} {incr i} {
	$ns_ connect $udp($i) $base0
}

$ns_ connect $udp(1) $base1

for {set i 1} {$i < [expr $val(nn) - 1] } {incr i} {
	$ns_ at [expr 2.0+$i] "$cbr($i) start"
}


# Tell nodes when the simulation ends

for {set i 0} {$i < $val(nn) } {incr i} {
    $ns_ at 40.0 "$node_($i) reset";
}
$ns_ at 40.0 "stop"
$ns_ at 40.0 "puts \"NS EXITING...\" ; $ns_ halt"

proc stop {} {
    global ns_ tracefd #namtrace
    $ns_ flush-trace
    close $tracefd
 #   close $namtrace

 #   puts "running nam..."
 #  exec nam 802.nam &
    exit 0
}

puts "Starting Simulation..."
$ns_ run
